@@ -179,8 +179,11 @@ class Node:
         else:
             return False
 
-    def add_foreign_account(self, key, name):
+    def add_foreign_account(self, key, name, password):
         copyfile(key, "{}/keystore/{}".format(self.datadir, name))
+        with open(key) as keyfile:
+            encrypted_key = keyfile.read()
+            private_key = self.w3.eth.account.decrypt(encrypted_key, password)
 
     def get_first_account(self):
         """
